**1.0.14 - 05/12/2020**

 - Add static data root.

**1.0.13 - 05/12/2020**

 - Add unversioned inputs root.

**1.0.12 - 05/12/2020**

 - Refactor of get_last_stage_directory to be a bit smarter.
 - Add NOAA data.

**1.0.11 - 05/01/2020**

 - Add a path for raw covariates.

**1.0.10 - 04/30/2020**

 - Add new paths for covariate gathering
 - Update cli tools to support QC functions.

**1.0.9 - 04/28/2020**

 - Adjust update with previous metadata.

**1.0.8 - 04/28/2020**

 - Error on bad production dir name.
 - Add output root for deaths model.
 - Extract some convenience functions to reduce cli boilerplate.

**1.0.7 - 04/26/2020**

 - Additional logging utilities
 - Better mkdir support
 - Expanded marking functions.

**1.0.6 - 04/22/2020**

 - Bugfix in symlink handling.
 - Add general method to create dirs with reasonable permissions.

**1.0.5 - 04/18/2020**

 - Add NY times output directory name.

**1.0.4 - 04/18/2020**

 - Add NY times repo path.
 - Add success flag to metadata when successful.

**1.0.3 - 04/16/2020**

 - Add tool tracking to metadata.

**1.0.2 - 04/14/2020**

 - Add authors, code of conduct, contributing guide.

**1.0.1 - 04/14/2020**

 - Deployment updates.

**1.0.0 - 04/14/2020**

 - Initial release.
